document.addEventListener('DOMContentLoaded', function () {
  // URL of the CSV file
  const csvUrl =
    'https://gist.githubusercontent.com/NithishSunkara/4f0dba0804dd02c75973aafe37d33f05/raw/97bdd4c04b3401a9fc965de7bd38a006c4c7ece4/T20stats.csv';

  // Load data from the CSV file using D3
  d3.csv(csvUrl)
    .then(function (data) {
      console.log('CSV data loaded:', data); // Log to check if data is loaded

      // Convert string values to numbers
      data.forEach(function (d) {
        d.Matches = +d.Matches;
        d.Runs = +d.Runs;
      });

      // Set up dimensions for the chart
      const margin = {
          top: 20,
          right: 20,
          bottom: 50,
          left: 50,
        },
        width = 800 - margin.left - margin.right,
        height = 400 - margin.top - margin.bottom;

      // Create SVG element
      const svg = d3
        .select('#areaChart')
        .append('svg')
        .attr('width', width + margin.left + margin.right)
        .attr('height', height + margin.top + margin.bottom)
        .append('g')
        .attr(
          'transform',
          'translate(' +
            margin.left +
            ',' +
            margin.top +
            ')',
        );

      // Create scales
      const x = d3
        .scaleLinear()
        .domain(d3.extent(data, (d) => d.Matches))
        .range([0, width]);

      const y = d3
        .scaleLinear()
        .domain([0, d3.max(data, (d) => d.Runs)])
        .range([height, 0]);

      // Create area generator
      const area = d3
        .area()
        .x((d) => x(d.Matches))
        .y0(height)
        .y1((d) => y(d.Runs));

      // Append area to SVG
      svg
        .append('path')
        .datum(data)
        .attr('fill', 'steelblue')
        .attr('d', area);

      // Create axes
      const xAxis = d3
        .axisBottom(x)
        .tickFormat(d3.format('d'));
      const yAxis = d3.axisLeft(y);

      // Append axes to SVG
      svg
        .append('g')
        .attr('transform', 'translate(0,' + height + ')')
        .call(xAxis)
        .append('text')
        .attr('x', width / 2)
        .attr('y', 40)
        .attr('fill', '#000')
        .style('text-anchor', 'middle')
        .text('Matches');

      svg
        .append('g')
        .call(yAxis)
        .append('text')
        .attr('transform', 'rotate(-90)')
        .attr('x', -height / 2)
        .attr('y', -40)
        .attr('fill', '#000')
        .style('text-anchor', 'middle')
        .text('Runs');
    })
    .catch(function (error) {
      console.error('Error loading the CSV data: ', error);
      alert('Error loading the CSV data: ' + error); // Alert for immediate feedback
    });
});
